CON

  _clkmode      = xtal1 + pll8x
  _xinfreq      = 10_000_000

'' Constants for grayscale display.

  BASEPIN       = 12   'Base pin for video output.
  GRAYPIN       = 15   'Pin to use for DUTY-mode gray levels.
  WIDTH         = 128  'WIDTH of grayscale area in pixels. (WIDTH & 7 == 0 AND WIDTH => 128)
  HEIGHT        = 96   'HEIGHT of grayscale area in pixels. (HEIGHT => 96)

'' Pin definitions for Propeller Backpack. Can be changed for other Propeller modules.

  SCL           = 4
  SDA           = 5
  VSYNC         = 6
  MCLK          = 7
  DATA          = 0
  HSYNC         = 3

DAT

  my_pins               byte    SCL, SDA, VSYNC, MCLK, DATA, HSYNC

VAR

  word histogram[16], minx, miny, maxx, maxy, avgx, avgy
  byte sync

OBJ

  txt :         "tv_wtext"
  cam :         "PropCAM_parallel4"
  ovl :         "tv_gray_overlay"
  img :         "ImageProcess4"
 
PUB start | changes, grab, prevx, prevy

  txt.start(BASEPIN)
  gray_buf_addr := @gray_buf
  sync_addr := @sync
  ovl.start(BASEPIN, GRAYPIN, @gray_buf, 95, 28, 2, @sync)
  cam.start(cam#SYNCED, @my_pins, @gray_buf_addr)
  img.start(@gray_buf)
  txt.str(string(txt#DEFWIN, 1, 2, 1, 35, 12, txt#USEWIN, 1, txt#USEWIN, txt#ZERO))
  txt.out(txt#HOME)
  grab := cam#GRAB_EVEN
  cam.acquire(grab)
  repeat
    cam.acquire(grab)
    changes := img.do(img#RECT | img#EODIF, 0, 0, 127, 95, img#UNDEF, img#UNDEF, $ff00, @histogram) 
    avgx := (avgx * 34) >> 7 
    avgy := avgy >> 3
    txt.str(string(txt#USEWIN, 1, txt#CRSRXY))
    txt.out(prevx)
    txt.out(prevy)
    txt.str(string(txt#SELCLR, 1, " "))
    if changes > 20
      txt.out(txt#CRSRXY)
      txt.out(avgx)
      txt.out(avgy)
      txt.str(string(txt#SELCLR, 9, txt#ESC, txt#CR, txt#USEWIN, txt#ZERO, txt#HOME, txt#SELCLR, 14))
      prevx := avgx
      prevy := avgy
      grab ^= cam#EVEN_TO_ODD
    else
      txt.str(string(txt#USEWIN, txt#ZERO, txt#HOME, txt#SELCLR, 12))
    txt.str(string("Change: "))
    txt.dec(changes)
    txt.out(txt#CR)


DAT

gray_buf      long      cam#PIXELS_PER_ROW << 16 | cam#ROWS_PER_FRAME, 0[cam#LONGS_PER_ROW * cam#ROWS_PER_FRAME]

gray_buf_addr word      0-0                     '@gray_buf gets plugged in here.
left          word      0                       'Lefmost pixel in gray_buf for capture.
top           word      0                       'Topmost oixel in gray_buf for capture.
exp_type      word      cam#AUTOBOTH            'Set exposure mode to automatically adjust gain and exposure time.
sync_addr     word      0-0                     '@sync gets plugged in here.
exp_time      word      20                      'Start with minimum exposure time.
gain          word      $0f                     'Start with medium gain.
target        word      600                     'Autoexposure target for avg_pix.
time_interval word      -30                     'Initial exporsure time = 1/30 sec.
avg_pix       word      0-0                     'Average pixel value from last capture * 100.